@@ -32,6 +32,7 @@
 #include "multipleAlign/Iteration.h"
 #include "tree/TreeInterface.h"
 #include "general/debuglogObject.h"
+#include "general/statsObject.h"
 #include "alignment/ObjectiveScore.h"
 #include "general/ClustalWResources.h"
 #include "Help.h"
@@ -84,6 +85,8 @@ void Clustal::align(string* phylipName, bool createOutput)
         return;
     }
 
+ 
+    
     userParameters->setStructPenalties1(NONE);
     userParameters->setStructPenalties2(NONE);
     
@@ -118,10 +121,11 @@ void Clustal::align(string* phylipName, bool createOutput)
     {
         alignmentObj.resetAlign();
     }
-
-    cout << "Start of Pairwise alignments\n";
-    cout << "Aligning...\n";
-    
+    if(userParameters->getDisplayInfo())
+    {
+        cout << "Start of Pairwise alignments\n";
+        cout << "Aligning...\n";
+    }
     if(userParameters->getDNAFlag()) 
     {
         userParameters->setDNAParams();
@@ -130,7 +134,12 @@ void Clustal::align(string* phylipName, bool createOutput)
     {
         userParameters->setProtParams();
     }
-   
+
+    if (statsObject->isEnabled()) {
+        statsObject->logInputSeqStats(&alignmentObj);
+    }
+
+       
     /// STEP 1: PAIRWISE ALIGNMENT TO GENERATE DISTANCE MATRIX 
     
     SymMatrix distMat;
@@ -211,8 +220,15 @@ void Clustal::align(string* phylipName, bool createOutput)
         Iteration iterateObj;
         iterateObj.removeFirstIterate(&alignmentObj);
         alignmentObj.calculateMaxLengths(); // Mark Change 20-6-07
-        cout << "Finished iteration\n";
+        if(userParameters->getDisplayInfo())
+            cout << "Finished iteration\n";
     }
+
+    if (statsObject->isEnabled()) {
+        statsObject->logAlignedSeqStats(&alignmentObj);
+    }
+
+
     
     /// STEP 4: OUTPUT THE ALIGNMENT 
     if(createOutput)
@@ -358,8 +374,11 @@ void Clustal::sequencesAlignToProfile(string* phylipName)
     
     if (useTree == false) // create the new tree file, if necessary
     {
-        cout << "Start of Pairwise alignments\n";
-        cout << "Aligning...\n";
+        if(userParameters->getDisplayInfo())
+        {
+            cout << "Start of Pairwise alignments\n";
+            cout << "Aligning...\n";
+        }
         
         if(userParameters->getDNAFlag()) 
         {
@@ -384,8 +403,9 @@ void Clustal::sequencesAlignToProfile(string* phylipName)
         // Generate distance matrix!
         pairwiseDist->pairwiseAlign(&alignmentObj, &distMat, 0, _numSeqs, newSeq-2, _numSeqs);
         delete pairwiseDist;
-        
-        cout << "\n\n";
+
+        if(userParameters->getDisplayInfo())
+            cout << "\n\n";
         
         TreeInterface calcSeqWeights;
         calcSeqWeights.getWeightsFromDistMat(&seqWeights, &distMat, &alignmentObj, 1,
@@ -653,8 +673,11 @@ void Clustal::doGuideTreeOnly(string* phylipName)
         userParameters->createParameterOutput();
     }
 
-    cout << "Start of Pairwise alignments\n";
-    cout << "Aligning...\n";
+    if(userParameters->getDisplayInfo())
+    {
+        cout << "Start of Pairwise alignments\n";
+        cout << "Aligning...\n";
+    }
     
     if(userParameters->getDNAFlag()) 
     {
@@ -773,9 +796,11 @@ void Clustal::doAlignUseOldTree(string* phylipName)
     }
     else 
     {
-        cout << "Start of Pairwise alignments\n";
-        cout << "Aligning...\n";
-        
+        if(userParameters->getDisplayInfo())
+        {
+            cout << "Start of Pairwise alignments\n";
+            cout << "Aligning...\n";
+        }
         if(userParameters->getDNAFlag()) 
         {
             userParameters->setDNAParams();
