@@ -63,7 +63,7 @@ Help::Help()
 "  \n"
 " -ITERATION=    :NONE or TREE or ALIGNMENT\n"
 " \n"
-" -NUMITER=n     :maximum number of iterations to perform\n"
+" -NUMITER=n     :Maximum number of iterations to perform\n"
 " \n"
 "==HELP==\n"
 " \n"        
@@ -71,7 +71,11 @@ Help::Help()
 " \n"
 "==MISC==\n"
 "\n"
-" -MAXSEQLEN=n   :maximum allowed sequence length\n"
+" -MAXSEQLEN=n   :Maximum allowed sequence length\n"
+" \n"        
+" -QUIET         :Reduce console output to minimum\n"
+" \n"
+" -STATS=file    :Log some alignents statistics to file\n"
 "";
     sections.push_back(s);
 
@@ -647,6 +651,8 @@ Help::Help()
 "-SEQNO_RANGE=:OFF or ON (NEW: for all output formats)\n"
 "-RANGE=m,n   :sequence range to write starting m to m+n\n"
 "-MAXSEQLEN=n :maximum allowed input sequence length\n"
+"-QUIET       :Reduce console output to minimum\n"        
+"-STATS=      :Log some alignents statistics to file\n"
 "\n"
 "***Fast Pairwise Alignments:***\n"
 "-KTUPLE=n    :word size\n"
@@ -680,6 +686,7 @@ Help::Help()
 "-TRANSWEIGHT=f :transitions weighting\n"
 "-ITERATION=    :NONE or TREE or ALIGNMENT\n"
 "-NUMITER=n     :maximum number of iterations to perform\n"
+"-NOWEIGHTS     :disable sequence weighting\n"
 "\n"
 "\n"
 "***Profile Alignments:***\n"
