@@ -75,7 +75,7 @@ AlignmentOutput::AlignmentOutput()
  */
 void AlignmentOutput::createAlignmentOutput(Alignment* alignPtr, int firstSeq, int lastSeq)
 {
-    int i, length;  
+    int length;  
     int firstRes; // starting sequence range - Ramu
     int lastRes; // ending sequence range 
     bool rangeOK;
@@ -131,7 +131,7 @@ void AlignmentOutput::createAlignmentOutput(Alignment* alignPtr, int firstSeq, i
         partToOutput._lastSeq = lastSeq;
         partToOutput._firstRes = firstRes;
         partToOutput._lastRes = lastRes;
-        
+
         if(userParameters->getOutputClustal()) 
         {
             if(clustalOutFile.get() != 0 && clustalOutFile->is_open())
@@ -1481,7 +1481,7 @@ void AlignmentOutput::nbrfOut(Alignment* alignPtr, outputRegion partToOutput)
         bool _dnaFlag = userParameters->getDNAFlag();
         namePrefix = _dnaFlag ? ">DL;" : ">P1;";
         
-        int length = lastRes - firstRes + 1; //- nige
+        //int length = lastRes - firstRes + 1; //- nige
 
         for(ii = firstSeq; ii <= lastSeq; ii++) 
         {
@@ -1594,8 +1594,8 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
         string tmpStr = "";
         string sequenceLine = "";
 
-        int _numSequences = alignPtr->getNumSeqs();
 
+        int _numSequences = alignPtr->getNumSeqs();
         // PMcG revert to Clustalw1.83 output format for name width
         const int NAMESWIDTH=std::max(std::min(MAXNAMESTODISPLAY,alignPtr->getMaxNames()) , MINNAMESTODISPLAY); 
 
@@ -1621,9 +1621,8 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                 }
             }
         }
-        
+
         seq1.assign(alignPtr->getMaxAlnLength() + 1, 0);
-        
         // Check if we have secondary structure in file 1 and if we want to output it.
         if (userParameters->getStructPenalties1() == SECST && 
             userParameters->getUseSS1() == true) 
@@ -1639,15 +1638,18 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
             printSecStructMask(lengthSeq1, _secStructMask1, &ss_mask1);
           
         }
-
+        
         // Check if we have secondary structure in file 2 and if we want to output it.
         if (userParameters->getStructPenalties2() == SECST && 
-            userParameters->getUseSS2() == true) 
+            userParameters->getUseSS2() == true &&
+            userParameters->getProfile2Empty() == false)
         {
+            // AW added test getProfile2Empty was meant to fix bug
+            // 141, but only prevents segfault, output still faulty.
+            // Has to be fixed somewhere else
             int indexProfile2FirstSeq = alignPtr->getProfile1NumSeqs() + 1;
             int lengthSeqProfile2 = alignPtr->getSeqLength(indexProfile2FirstSeq);
             ss_mask2.assign(lengthSeqProfile2 + 10, 0);
-            
             vector<char>* _secStructMask2 = alignPtr->getSecStructMask2();
             for (i = 0; i < lengthSeqProfile2; i++)
             {
@@ -2385,7 +2387,7 @@ int AlignmentOutput::SeqGCGCheckSum(vector<char>* seq, int length)
     int i;
     long check;
     int seqResIndex = 1;
-    int seqLength = seq->size();
+    //int seqLength = seq->size();
     
     for (i = 0, check = 0; i < length; i++, seqResIndex++)
     {
