@@ -31,7 +31,10 @@ namespace clustalw
 using namespace std;
  
 UserParameters::UserParameters(bool log)
-{   
+{
+   // FIXME: huge parts should be merged/replaced with
+   // setParamsToDefault (which is not used at all)
+   
     gapPos1 = NUMRES - 2; /* code for gaps inserted by clustalw */
     gapPos2 = NUMRES - 1; /* code for gaps already in alignment */
     
@@ -167,8 +170,11 @@ UserParameters::UserParameters(bool log)
     displayInfo = true;
     helpFlag = false;
     fullHelpFlag = false;
+    quiet = false;
+    
 }
 
+// FIXME:never used
 void UserParameters::setParamsToDefault()
 {
     DNAGapOpen = 15.0;
@@ -271,6 +277,7 @@ void UserParameters::setParamsToDefault()
     displayInfo = true; 
     helpFlag = false;
     fullHelpFlag = false;
+    quiet = false;
     doRemoveFirstIteration = NONE;
     maxAllowedSeqLength = INT_MAX;
 }
@@ -1329,8 +1336,6 @@ bool UserParameters::IterationIsEnabled()
     else
         return true;
 }
-
-
 }
 
 
