@@ -12,6 +12,10 @@
 #include <fstream>
 #include "CommandLineParser.h"
 #include "../substitutionMatrix/globalmatrix.h"
+#include "general/Utility.h"
+#include "general/statsObject.h"
+
+
 
 using namespace std;
 
@@ -22,6 +26,7 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
    :setOptions(-1),
     setHelp(-1),
     setFullHelp(-1),
+    setQuiet(-1),
     setInteractive(-1),
     setBatch(-1),
     setGapOpen(-1),
@@ -92,7 +97,8 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     setDoIteration(-1),
     setNumIterations(-1),
     setTreeAlgorithm(-1),
-    setMaxSeqLen(-1)
+    setMaxSeqLen(-1),
+    setStatsFile(-1)
 {
     int ctr=0;
     
@@ -213,8 +219,9 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     
     ctr=0;
     cmdLineVerb[ctr++] = getCmdLineDataStruct("help", &setHelp, NOARG, NULL);
-    cmdLineVerb[ctr++] = getCmdLineDataStruct("check", &setHelp, NOARG, NULL);
     cmdLineVerb[ctr++] = getCmdLineDataStruct("fullhelp", &setFullHelp, NOARG, NULL);
+    cmdLineVerb[ctr++] = getCmdLineDataStruct("quiet", &setQuiet, NOARG, NULL);
+    cmdLineVerb[ctr++] = getCmdLineDataStruct("check", &setHelp, NOARG, NULL);
     cmdLineVerb[ctr++] = getCmdLineDataStruct("options", &setOptions, NOARG, NULL);
     cmdLineVerb[ctr++] = getCmdLineDataStruct("align", &setAlign, NOARG, NULL);
     cmdLineVerb[ctr++] = getCmdLineDataStruct("newtree", &setNewTree, FILARG, NULL);
@@ -233,7 +240,7 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     cmdLineVerb[ctr++] = getCmdLineDataStruct("iteration", &setDoIteration, 
                                            OPTARG, iterationArg);
     cmdLineVerb[ctr++] = getCmdLineDataStruct("", NULL, -1, NULL);
-    // FIXME: final ctr index is hardcoded in CommandLineParser
+    // FIXME: final ctr index is hardcoded in CommandLineParser.h
     
     // NOTE Start back here!!!!!!!!!!!!
     ctr=0;
@@ -296,6 +303,7 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     cmdLinePara[ctr++] = getCmdLineDataStruct("clustering", &setTreeAlgorithm, OPTARG,
                                            clusterAlgorithm);
     cmdLinePara[ctr++] = getCmdLineDataStruct("maxseqlen", &setMaxSeqLen, INTARG, NULL);
+    cmdLinePara[ctr++] = getCmdLineDataStruct("stats", &setStatsFile, FILARG, NULL);
     cmdLinePara[ctr++] = getCmdLineDataStruct("", NULL, -1, NULL);
     // FIXME: final ctr index is hardcoded in CommandLineParser
     
@@ -342,7 +350,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     bool doAlign, doConvert, doAlignUseOldTree, doGuideTreeOnly, doTreeFromAlign, 
          doBootstrap, doProfileAlign, doSomething;
 
-    if (!xmenus)
+    if (!xmenus && userParameters->getDisplayInfo())
     {
         cout << "\n\n\n";
         cout << " CLUSTAL " << userParameters->getRevisionLevel() 
@@ -350,8 +358,8 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     }
 
     doAlign = doConvert = doAlignUseOldTree = doGuideTreeOnly = doTreeFromAlign = false;
-    doBootstrap = doProfileAlign = doSomething = false;
-
+    doBootstrap = doProfileAlign = doSomething = false; 
+    
     numparams = checkParam(args, params, paramArg);
     
     if (numparams < 0) 
@@ -387,7 +395,17 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
             exit(1);
         }
     }
- 
+
+    if(setQuiet != -1) 
+    {
+        userParameters->setDisplayInfo(false);
+        utilityObject->beQuiet(true);
+    } else {
+        userParameters->setDisplayInfo(true);
+        utilityObject->beQuiet(false);
+    }
+
+        
     // need to check maxseqlen before reading input file
     if (setMaxSeqLen != -1)
     {
@@ -417,6 +435,14 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         
     }
 
+    if (setStatsFile != -1)
+    {
+        if((*paramArg)[setStatsFile].length() > 0) 
+        {
+            statsObject->setEnabled(true);
+            statsObject->setStatsFile((*paramArg)[setStatsFile]);
+        }
+    }
 
     
     /*if(setDoIteration != -1)
@@ -467,7 +493,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         
         for (i = 0; cmdLineVerb[i].str[0] != '\0'; i++) 
         {
-            cout << "\t\t" << COMMANDSEP << cmdLineVerb[i].str 
+            cout << "\t\t" << default_commandsep << cmdLineVerb[i].str 
                  << (*cmdLineType)[cmdLineVerb[i].type];
 
             if (cmdLineVerb[i].type == OPTARG) 
@@ -485,7 +511,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         }
         for (i = 0; cmdLineFile[i].str[0] != '\0'; i++) 
         {
-            cout<<"\t\t" << COMMANDSEP << cmdLineFile[i].str 
+            cout<<"\t\t" << default_commandsep << cmdLineFile[i].str 
                 << (*cmdLineType)[cmdLineFile[i].type];
                 
             if (cmdLineFile[i].type == OPTARG) 
@@ -504,7 +530,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         }
         for (i = 0; cmdLinePara[i].str[0] != '\0'; i++) 
         {
-            cout <<"\t\t" << COMMANDSEP << cmdLinePara[i].str 
+            cout <<"\t\t" << default_commandsep << cmdLinePara[i].str 
                  << (*cmdLineType)[cmdLinePara[i].type];
      
             if (cmdLinePara[i].type == OPTARG) 
@@ -667,6 +693,11 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     if (setInteractive != -1)
     {
         userParameters->setInteractive(true);
+        if (setQuiet!=-1) {
+            cout << "interactive menu: overriding -quiet\n";
+            userParameters->setDisplayInfo(true);
+            utilityObject->beQuiet(false);
+        }
     }
 
     if (userParameters->getInteractive()) 
@@ -943,7 +974,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     }
 
 
-
+    
 
 //***************************************************************************
 // Now do whatever has been requested ***************************************
@@ -1050,7 +1081,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
                 logObject->logMsg("    Doing Bootstrap");
             }
         #endif            
-        clustalObj->bootstrapTree(&phylipTreeName, &clustalTreeName, &nexusTreeName);
+            clustalObj->bootstrapTree(&phylipTreeName, &clustalTreeName, &nexusTreeName);
     }
 
     cout << "\n";
@@ -1083,8 +1114,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
         return 0;
     }
 
-    // AW: first arg is an input file if it doesnt start with COMMANDSEP
-    if ((*args)[0][0] != COMMANDSEP)
+    // AW: first arg is an input file if it doesnt start with commandsep
+    if (VALID_COMMAND_SEP.find((*args)[0][0], 0) == string::npos)
     {
         name1 = true;
         params->push_back((*args)[0]); // Put the string at the back of this vector.
@@ -1103,7 +1134,7 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
         {
             if(isprint((*args)[i][j + 1])) // Character printable?
             {
-                // We start at j + 1 because each option should begin with COMMANDSEP
+                // We start at j + 1 because each option should begin with commandsep
                 (*params)[i].append((*args)[i].substr(j + 1, 1));
             }
         }
@@ -1309,7 +1340,7 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
     {
         if (match[i] == -1) 
         {
-            cout << "Error: unknown option " << COMMANDSEP << (*params)[i] << endl;
+            cout << "Error: unknown option " << default_commandsep << (*params)[i] << endl;
             exit(1);
         }
     }
@@ -2337,6 +2368,7 @@ void CommandLineParser::setOptionalParam()
     //*** ? /bootlabels=n 
     if(setBootLabels != -1) 
     {
+
         #if DEBUGFULL 
             if(logObject && DEBUGLOG)
             {
@@ -2359,7 +2391,7 @@ void CommandLineParser::setOptionalParam()
         }
         else
         {
-            cout << "\nUnknown bootlabels type " << (*paramArg)[setOutOrder] << endl;
+            cout << "\nUnknown bootlabels type " << (*paramArg)[setBootLabels] << endl;
         }
     }
 
